@@ -58,7 +58,7 @@ $lang = array_merge($lang, array(
 	'ATTACH_EXT_GROUPS_URL'				=> 'קבוצות סיומות',
 	'ATTACH_ID'							=> 'ID',
 	'ATTACH_MAX_FILESIZE'				=> 'גודל קובץ מירבי',
-	'ATTACH_MAX_FILESIZE_EXPLAIN'		=> 'גודל מירבי של כל קובץ, כאשר 0 הינו בלתי מוגבל.',
+	'ATTACH_MAX_FILESIZE_EXPLAIN'		=> 'גודל מירבי של כל קובץ. אם הערך הוא 0,  המגבלה היחידה נקבעת בהגדרות ה-PHP בשרת.',
 	'ATTACH_MAX_PM_FILESIZE'			=> 'גודל קובץ מירבי להודעה פרטית',
 	'ATTACH_MAX_PM_FILESIZE_EXPLAIN'	=> 'גודל מירבי של קובץ, מצורף להודעה הפרטית, כאשר 0 הינו בלתי מוגבל.',
 	'ATTACH_ORPHAN_URL'					=> 'קבצים מצורפים ללא שולח',
