@@ -110,7 +110,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'מימדי סמל אישי מקסימלים',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'רוחב x גובה בפיקסלים.',
 	'MAX_FILESIZE'					=> 'גודל קובץ לסמל אישי מירבי',
-	'MAX_FILESIZE_EXPLAIN'			=> 'לקבצי סמלים אישיים שהועלו.',
+	'MAX_FILESIZE_EXPLAIN'			=> 'לקבצי סמלים אישיים שהועלו. אם הערך הוא 0,  המגבלה היחידה נקבעת בהגדרות ה-PHP בשרת.',
 	'MIN_AVATAR_SIZE'				=> 'מימדי סמל אישי מינימלים',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'רוחב x גובה בפיקסלים.',
 ));
@@ -394,7 +394,7 @@ $lang = array_merge($lang, array(
 	'LDAP_EMAIL_EXPLAIN'			=> 'קבע לשם של תכונת הדואר האלקטרוני של רישום המשתמש (אם אחד קיים) כדי לקבוע אוטומטית את כתובת הדואר האלקטרוני למשתמשים חדשים. השארת השדה ריק תגרום לכתובת דואר אלקטרוני ריקה למשתמשים אשר מתחברים בפעם הראשונה.',
 	'LDAP_INCORRECT_USER_PASSWORD'	=> 'קישור לשרת LDAP נכשל עם המשתמש/הסיסמה שצויינו.',
 	'LDAP_NO_EMAIL'					=> 'תכונת הדואר האלקטרוני שצוינה לא קיימת.',
-	'LDAP_NO_IDENTITY'				=> 'לא ניתן למצוא זיהוי חיבור ל %s.',
+	'LDAP_NO_IDENTITY'				=> 'לא ניתן למצוא זיהוי חיבור ל%s.',
 	'LDAP_PASSWORD'					=> 'סיסמה ל LDAP',
 	'LDAP_PASSWORD_EXPLAIN'			=> 'השאר ריק כדי להשתמש בגישה אנונימית. אחרת מלא את הסיסמה למשתמש שמעל. נדרש לשרתי תיקיה פעילים.<br /><em><strong>אזהרה:</strong> הסיסמה תאוחסן כטקסט פשוט בבסיס הנתונים, ותוצג לכל אחד אשר יכול לגשת לבסיס הנתונים או אשר יכול לצפות בעמוד ההגדרות.</em>',
 	'LDAP_PORT'						=> 'יציאת שרת LDAP',
