@@ -97,10 +97,10 @@ $lang = array_merge($lang, array(
 	'ACP_GLOBAL_MODERATORS'			=> 'מנהלים גלובאלים',
 	'ACP_GLOBAL_PERMISSIONS'		=> 'הרשאות גלובאליות',
 	'ACP_GROUPS'					=> 'קבוצות',
-	'ACP_GROUPS_FORUM_PERMISSIONS'	=> 'הרשאות פורום של קבוצות',
+	'ACP_GROUPS_FORUM_PERMISSIONS'	=> 'הרשאות פורום של קבוצה',
 	'ACP_GROUPS_MANAGE'				=> 'ניהול קבוצות',
-	'ACP_GROUPS_MANAGEMENT'			=> 'ניהול קבוצות',
-	'ACP_GROUPS_PERMISSIONS'		=> 'הרשאות של קבוצות',
+	'ACP_GROUPS_MANAGEMENT'			=> 'ניהול קבוצה',
+	'ACP_GROUPS_PERMISSIONS'		=> 'הרשאות של קבוצה',
 	
 	'ACP_ICONS'					=> 'סמלי נושאים',
 	'ACP_ICONS_SMILIES'			=> 'סמלי/סמיילים של נושאים',
@@ -171,9 +171,9 @@ $lang = array_merge($lang, array(
 	'ACP_THEMES'				=> 'סגנונות',
 	
 	'ACP_UPDATE'					=> 'עדכון',
-	'ACP_USERS_FORUM_PERMISSIONS'	=> 'הרשאות פורום של משתמשים',
-	'ACP_USERS_LOGS'				=> 'מעקב אחר פעולות משתמשים',
-	'ACP_USERS_PERMISSIONS'			=> 'הרשאות של משתמשים',
+	'ACP_USERS_FORUM_PERMISSIONS'	=> 'הרשאות פורום של משתמש',
+	'ACP_USERS_LOGS'				=> 'יומן פעולות משתמש',
+	'ACP_USERS_PERMISSIONS'			=> 'הרשאות משתמש',
 	'ACP_USER_ATTACH'				=> 'קבצים מצורפים',
 	'ACP_USER_AVATAR'				=> 'סמל אישי',
 	'ACP_USER_FEEDBACK'				=> 'משוב',
@@ -347,7 +347,7 @@ $lang = array_merge($lang, array(
 	'NUMBER_USERS'		=> 'מספר משתמשים',
 	'NUMBER_ORPHAN'		=> 'קבצים מצורפים ללא שולח',
 	
-	'PHP_VERSION_OLD'	=> 'גירסאת הPHP שבשרת זה לא תתמך על ידי גרסאות עתידיות של phpBB. %sפרטיםs%s',
+	'PHP_VERSION_OLD'	=> 'גירסאת הPHP שבשרת זה לא תתמך על ידי גרסאות עתידיות של phpBB. %sפרטים%s',
 	'POSTS_PER_DAY'		=> 'הודעות ליום',
 
 	'PURGE_CACHE'			=> 'טיהור המטמון',
@@ -402,7 +402,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'		=> 'לא ידוע',
 	'INACTIVE_USERS'				=> 'משתמשים לא פעילים',
 	'INACTIVE_USERS_EXPLAIN'		=> 'זוהי רשימת המשתמשים הרשומים אשר חשבונם אינו פעיל. אתה יכול להפעיל, למחוק או להזכיר (על-ידי שליחת דואר אלקטרוני) למשתמשים אלו אם תרצה.',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'זוהי רשימת 10 המשתמשים האחרונים שנרשמו, אשר חשבונם אינו פעיל. את רשימת כל המשתמשים שאינם פעילים ניתן למצוא בקישור הבא:',
+	'INACTIVE_USERS_EXPLAIN_INDEX'   => 'זוהי רשימת 10 המשתמשים האחרונים שנרשמו אשר חשבונם אינו פעיל. חשבונות לא פעילים או בגלל שהפעלת חשבון הופעלה בהגדרות רישום משתמש וחשבונות משתמשים אלו טרם הופעלו, או בגלל שחשבונות אלו בוטלו. רשימה מלאה זמינה על ידי לחיצה על הקישור שמופיע מטה, משם אתה יכול להפעיל, למחוק או להזכיר (על-ידי שליחת דואר אלקטרוני) למשתמשים אלו אם תרצה.',
 	'NO_INACTIVE_USERS'	=> 'אין משתמשים לא פעילים',
 
 	'SORT_INACTIVE'		=> 'תאריך ללא פעילות',
@@ -520,7 +520,7 @@ $lang = array_merge($lang, array(
 	'LOG_LOCK'					=> '<strong>נעל נושא</strong><br />» %s',
 	'LOG_LOCK_POST'				=> '<strong>נעל הודעה</strong><br />» %s',
 	'LOG_MERGE'					=> '<strong>מיזג הודעות</strong> לתוך נושא<br />» %s',
-	'LOG_MOVE'					=> '<strong>העביר נושא</strong><br />» מ %1$s ל %2$s',
+	'LOG_MOVE'					=> '<strong>העביר נושא</strong><br />» מ%1$s ל%2$s',
 	'LOG_PM_REPORT_CLOSED'		=> '<strong>סגר דיווח הודעה פרטית</strong><br />» %s',
 	'LOG_PM_REPORT_DELETED'		=> '<strong>מחק דיווח הודעה פרטית</strong><br />» %s',
 	'LOG_POST_APPROVED'			=> '<strong>אישר הודעה</strong><br />» %s',
@@ -529,7 +529,7 @@ $lang = array_merge($lang, array(
 	'LOG_REPORT_CLOSED'			=> '<strong>סגר דיווח</strong><br />» %s',
 	'LOG_REPORT_DELETED'		=> '<strong>מחק דיווח</strong><br />» %s',
 	'LOG_SPLIT_DESTINATION'		=> '<strong>העביר הודעות מפוצלות</strong><br />» אל %s',
-	'LOG_SPLIT_SOURCE'			=> '<strong>פיצל הודעות</strong><br />» מ %s',
+	'LOG_SPLIT_SOURCE'			=> '<strong>פיצל הודעות</strong><br />» מ%s',
 
 	'LOG_TOPIC_APPROVED'		=> '<strong>אישר נושא</strong><br />» %s',
 	'LOG_TOPIC_DISAPPROVED'		=> '<strong>דחה נושא “%1$s” בגלל הסיבה הבאה</strong><br />%2$s',
