@@ -41,10 +41,10 @@ $lang = array_merge($lang, array(
 		<p>ההרשאות מקובצות ומשתייכות לארבעה חלקים עיקריים, שהם:</p>
 
 		<h2>הרשאות גלובאליות</h2>
-		<p>הן בשימוש לשליטה בהרשאה ברמה גלובאלית ושייכות למערכת הפורום בשלמותה. הן בנוסף מתחלקות להרשאות של משתמשים, הרשאות של קבוצות, מנהלים ראשיים ומנהלים גלובאלים.</p>
+		<p>הן בשימוש לשליטה בהרשאה ברמה גלובאלית ושייכות למערכת הפורום בשלמותה. הן בנוסף מתחלקות להרשאות של משתמש, הרשאות של קבוצה, מנהלים ראשיים ומנהלים גלובאלים.</p>
 
 		<h2>הרשאות לפי פורומים</h2>
-		<p>הן בשימוש לשליטה בהרשאה בכל פורום. הן בנוסף נחלקות להרשאות פורום, מנהלי פורום, הרשאות פורום של משתמשים והרשאות פורום של קבוצות.</p>
+		<p>הן בשימוש לשליטה בהרשאה בכל פורום. הן בנוסף נחלקות להרשאות פורום, מנהלי פורום, הרשאות פורום של משתמש והרשאות פורום של קבוצה.</p>
 
 		<h2>כללי הרשאות</h2>
 		<p>הן בשימוש ליצירת ערכות שונות של הרשאות לסוגי ההרשאה השונים אשר אחר כך יכולים להקבע לפי כלל. כללי ברירת המחדל אמורים להיות הניהול הראשי של מערכות פורומים גדולות וקטנות, אך בכל אחד מארבעת החלקים, אתה יכול להוסיף/לערוך/למחוק כללים כפי שתרצה.</p>
@@ -84,13 +84,13 @@ $lang = array_merge($lang, array(
 	'ACP_FORUM_PERMISSIONS_COPY_EXPLAIN'		=> 'כאן אתה יכול להעתיק הרשאות פורום מפורום אחד לפורום אחד או יותר אחרים.',
 	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> 'כאן אתה יכול לקבוע הרשאות מנהל גלובאלי למשתמשים או קבוצות. מנהלים אלו הם כמו מנהלים רגילים אך להם יש הרשאה לכל הפורומים במערכת.',
 	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'		=> 'כאן אתה יכול לקבוע הרשאות פורום לקבוצות.',
-	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'כאן אתה יכול לקבוע הרשאות גלובאליות לקבוצות - הרשאות משתמש, הרשאות מנהל גלובאלי והרשאות מנהל ראשי. הרשאות משתמש כוללות יכולות כמו שימוש בסמלים אישיים, שליחת הודעות פרטות, וכדומה. הרשאות מנהל גלובאלי כוללות יכולות כמו אישות הודעות, ניהול נושאים, ניהול חסימות, וכדומה, ולבסוף הרשאות מנהל ראשי כוללות יכולות כמו שינוי הרשאות, הגדרת תגי BBCode מותאמים אישית, ניהול פורומים, וכדומה. הרשאות משתמשים יחידים מומלץ לשנות במקרים נדירים, השיטה המועדפת היא הכנסת משתמשים לקבוצות וקביעת הרשאות הקבוצה.',
+	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'כאן אתה יכול לקבוע הרשאות גלובאליות לקבוצות - הרשאות משתמש, הרשאות מנהל גלובאלי והרשאות מנהל ראשי. הרשאות משתמש כוללות יכולות כמו שימוש בסמלים אישיים, שליחת הודעות פרטות, וכדומה. הרשאות מנהל גלובאלי כוללות יכולות כמו אישות הודעות, ניהול נושאים, ניהול חסימות, וכדומה, ולבסוף הרשאות מנהל ראשי כוללות יכולות כמו שינוי הרשאות, הגדרת תגי BBCode מותאמים אישית, ניהול פורומים, וכדומה. הרשאות משתמש יחיד מומלץ לשנות במקרים נדירים, השיטה המועדפת היא הכנסת משתמשים לקבוצות וקביעת הרשאות לקבוצה.',
 	'ACP_ADMIN_ROLES_EXPLAIN'					=> 'כאן אתה יכול לנהל את הכללים להרשאות הניהול הראשי. הכללים הם הרשאות פעילות, אם אתה משנה כלל, הרכיבים אשר להם הכלל נקבע ישנו את ההרשאות שלהם גם כן.',
 	'ACP_FORUM_ROLES_EXPLAIN'					=> 'כאן אתה יכול לנהל את הכללים להרשאות הפורום. הכללים הם הרשאות פעילות, אם אתה משנה כלל, הרכיבים אשר להם הכלל נקבע ישנו את ההרשאות שלהם גם כן.',
 	'ACP_MOD_ROLES_EXPLAIN'						=> 'כאן אתה יכול לנהל את הכללים להרשאות הניהול. הכללים הם הרשאות פעילות, אם אתה משנה כלל, הרכיבים אשר להם הכלל נקבע ישנו את ההרשאות שלהם גם כן.',
 	'ACP_USER_ROLES_EXPLAIN'					=> 'כאן אתה יכול לנהל את הכללים להרשאות משתמש. הכללים הם הרשאות פעילות, אם אתה משנה כלל, הרכיבים אשר להם הכלל נקבע ישנו את ההרשאות שלהם גם כן.',
 	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> 'כאן אתה יכול לקבוע הרשאות פורום למשתמשים.',
-	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'כאן אתה יכול לקבוע הרשאות גלובאליות למשתמשים - הרשאות משתמש, הרשאות מנהל גלובאלי והרשאות מנהל ראשי. הרשאות משתמש כוללות יכולות כמו שימוש בסמלים אישיים, שליחת הודעות פרטות, וכדומה. הרשאות מנהל גלובאלי כוללות יכולות כמו אישות הודעות, ניהול נושאים, ניהול חסימות, וכדומה, ולבסוף הרשאות מנהל ראשי כוללות יכולות כמו שינוי הרשאות, הגדרת תגי BBCode מותאמים אישית, ניהול פורומים, וכדומה. הרשאות של משתמש מומלץ לשנות במקרים נדירים, השיטה המועדפת היא הכנסת משתמשים לקבוצות וקביעת הרשאות הקבוצה.',
+	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'כאן אתה יכול לקבוע הרשאות גלובאליות למשתמשים - הרשאות משתמש, הרשאות מנהל גלובאלי והרשאות מנהל ראשי. הרשאות משתמש כוללות יכולות כמו שימוש בסמלים אישיים, שליחת הודעות פרטות, וכדומה. הרשאות מנהל גלובאלי כוללות יכולות כמו אישות הודעות, ניהול נושאים, ניהול חסימות, וכדומה, ולבסוף הרשאות מנהל ראשי כוללות יכולות כמו שינוי הרשאות, הגדרת תגי BBCode מותאמים אישית, ניהול פורומים, וכדומה. הרשאות משתמש יחיד מומלץ לשנות במקרים נדירים, השיטה המועדפת היא הכנסת משתמשים לקבוצות וקביעת הרשאות לקבוצה.',
 	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'		=> 'כאן אתה יכול לצפות בהרשאות הניהול הראשי הפעילות אשר נקבעו למשתמשים/לקבוצות הנבחרים.',
 	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS_EXPLAIN'	=> 'כאן אתה יכול לצפות בהרשאות הניהול הגלובאלי אשר נקבעו למשתמשים/לקבוצות הנבחים.',
 	'ACP_VIEW_FORUM_PERMISSIONS_EXPLAIN'		=> 'כאן אתה יכול לצפות בהרשאות הפורום אשר נקבעו למשתמשים/לקבוצות ולפורומים הנבחרים.',
@@ -155,7 +155,7 @@ $lang = array_merge($lang, array(
 	'RESULTING_PERMISSION'			=> 'תוצאת הרשאה',
 	'ROLE'							=> 'כלל',
 	'ROLE_ADD_SUCCESS'				=> 'הכלל נוסף בהצלחה.',
-	'ROLE_ASSIGNED_TO'				=> 'משתמשים/קבוצות שנקבעו ל %s',
+	'ROLE_ASSIGNED_TO'				=> 'משתמשים/קבוצות שנקבעו ל%s',
 	'ROLE_DELETED'					=> 'הכלל הוסר בהצלחה.',
 	'ROLE_DESCRIPTION'				=> 'תיאור הכלל',
 
@@ -172,7 +172,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_POLLS'			=> 'הרשאה רגילה + סקרים',
 	'ROLE_FORUM_READONLY'		=> 'הרשאה לקריאה בלבד',
 	'ROLE_FORUM_STANDARD'		=> 'הרשאה רגילה',
-	'ROLE_FORUM_NEW_MEMBER'		=> 'משתמש שנרשם לאחרונה',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'הרשאת משתמש שנרשם לאחרונה',
 	'ROLE_MOD_FULL'				=> 'מנהל מלא',
 	'ROLE_MOD_QUEUE'			=> 'חצי מנהל',
 	'ROLE_MOD_SIMPLE'			=> 'מנהל פשוט',
@@ -182,7 +182,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> 'ללא סמל אישי',
 	'ROLE_USER_NOPM'			=> 'ללא הודעות פרטיות',
 	'ROLE_USER_STANDARD'		=> 'מאפיינים רגילים',
-	'ROLE_USER_NEW_MEMBER'		=> 'משתמש שנרשם לאחרונה',
+	'ROLE_USER_NEW_MEMBER'		=> 'מאפיינים למשתמש שנרשם לאחרונה',
 
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'יכול לגשת לניהול הפורום והגדרות הרשאת הפורום.',
 	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'בעל הרשאה לכל אפשרויות הניהול הראשי של המערכת.<br />לא מומלץ.',
@@ -225,8 +225,8 @@ $lang = array_merge($lang, array(
 	'SELECT_TYPE'					=> 'בחר סוג',
 	'SET_PERMISSIONS'				=> 'קבע הרשאות',
 	'SET_ROLE_PERMISSIONS'			=> 'קבע הרשאות כלל',
-	'SET_USERS_PERMISSIONS'			=> 'קבע הרשאות משתמשים',
-	'SET_USERS_FORUM_PERMISSIONS'	=> 'קבע הרשאות פורום של משתמשים',
+	'SET_USERS_PERMISSIONS'			=> 'קבע הרשאות משתמש',
+	'SET_USERS_FORUM_PERMISSIONS'	=> 'קבע הרשאות פורום של משתמש',
 
 	'TRACE_DEFAULT'					=> 'כברירת מחדל כל הרשאה היא <samp>לא</samp> (מבוטלת). ההרשאה יכולה להשתנות על-ידי הגדרות אחרות.',
 	'TRACE_FOR'						=> 'אתר ל',
@@ -273,7 +273,7 @@ $lang = array_merge($lang, array(
 	'TRACE_WHO'								=> 'מי',
 	'TRACE_TOTAL'							=> 'סך הכל',
 
-	'USERS_NOT_ASSIGNED'			=> 'אין משתמש שנקבע לכלל זה',
+	'USERS_NOT_ASSIGNED'			=> 'אין משתמשים שנקבעו לכלל זה',
 	'USER_IS_MEMBER_OF_DEFAULT'             => 'הוא חבר בקבוצות המוגדרות מראש הבאות',
 	'USER_IS_MEMBER_OF_CUSTOM'              => 'הוא חבר בקבוצות המשתמש המוגדרות הבאות',
 	'USER_GROUP_NORMAL'                             => 'קבוצות משתמש שהמשתמש חבר בהם',
