@@ -192,7 +192,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'          => 'הטופס שנשלח לא תקין. נסה לשלוח שנית.',
 	'FORUM'					=> 'פורום',
 	'FORUMS'				=> 'פורומים',
-	'FORUMS_MARKED'			=> 'הפורומים הנבחרים סומנו כנקראו.',
+	'FORUMS_MARKED'			=> 'הפורומים סומנו כנקראו.',
 	'FORUM_CAT'				=> 'קטגוריות הפורום',
 	'FORUM_INDEX'			=> 'עמוד ראשי',
 	'FORUM_LINK'			=> 'פורום קישור',
@@ -450,6 +450,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> 'זמן ההודעה',
 	'POST_TOPIC'			=> 'פרסם נושא חדש',
 	'POST_UNAPPROVED'		=> 'הודעה זו מחכה לאישור',
+	'POWERED_BY'			=> 'מופעל על-ידי %s',
 	'PREVIEW'				=> 'תצוגה מקדימה',
 	'PREVIOUS'				=> 'הקודם',		// Used in pagination
 	'PREVIOUS_STEP'			=> 'הקודם',
@@ -459,6 +460,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'		=> 'התכתבות פרטית',
 	'PROFILE'				=> 'לוח בקרה למשתמש',
 
+	'RANK'						=> 'דרגה',
 	'READING_FORUM'				=> 'צופה בנושאים ב%s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'קורא הכרזה גלובאלית',
 	'READING_LINK'				=> 'עובר בקישור לפורום %s',
