@@ -335,7 +335,7 @@ $help = array(
 	),
 	array(
 		0 => 'מדוע אפשרות X ניתנת?',
-		1 => 'המערכת נכתבה וקיבלה רישיון על ידי קבוצת phpBB. אם אתה רואה שיש אפשרות שלא קיימת ותועיל מאוד, אנא בקר באתר הרישמי phpbb.com ותקבל את תגובות המפתחים לגבי העיניין. אנא אל תשלח בקשות עתידיות למערכת ב phpbb.com.אנא ראה את הפורום קודם וודא שלא שלחו כבר רעיון כמו שלך.'
+		1 => 'המערכת נכתבה וקיבלה רישיון על ידי קבוצת phpBB. אם אתה רואה שיש אפשרות שלא קיימת ותועיל מאוד, או אם אתה מעוניין לדווח על תקלה, אנא בקר <a href="http://area51.phpbb.com/">באתר הפיתוח</a> של phpbb.com ותמצא את כל הכלים לעשות זאת.'
 	),
 	array(
 		0 => 'למי אני פונה במקרים של חוקתיות ואישורים למערכת?',
