@@ -138,7 +138,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'				=> 'הוסף תיקיה…',
 	'CURRENT_IMAGE'				=> 'תמונה נוכחית',
 	'CURRENT_PASSWORD'			=> 'סיסמה נוכחית',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'אתה חייב לאשר את סיסמתך הנוכחית אם אתה מעונין לשנות אותה, לשנות את כתובת הדואר האלקטרוני או שם המשתמש.',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'אתה חייב להזין את סיסמתך הנוכחית אם ברצונך לשנות את כתובת הדואר האלקטרוני שלך או את שם המשתמש.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'על מנת לשנות את סיסמתך, כתובת הדואר האלקטרוני שלך, או שם המשתמש שלך, אתה חייב להזין את סיסמתך הנוכחית.',
 	'CUR_PASSWORD_EMPTY'		=> 'לא הזנת את הסיסמא הנוכחית.',
 	'CUR_PASSWORD_ERROR'		=> 'הסיסמה הנוכחית שהזנת שגויה.',
 	'CUSTOM_DATEFORMAT'			=> 'מותאם אישית…',
@@ -388,6 +389,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'הכלל נוסף בהצלחה.',
 	'RULE_ALREADY_DEFINED'				=> 'כלל זה הוגדר כבר קודם לכן.',
 	'RULE_DELETED'						=> 'הכלל הוסר בהצלחה.',
+	'RULE_LIMIT_REACHED'				=> 'אינך יכול להוסיף יותר כללים להודעות הפרטיות. הגעת למקסימום הכללים שניתן להגדיר.',
 	'RULE_NOT_DEFINED'					=> 'הכלל לא צוין כראוי.',
 	'RULE_REMOVED_MESSAGE'				=> 'הודעה פרטית אחת הועברה מחדש עקב מסנני ההודעות הפרטיות.',
 	'RULE_REMOVED_MESSAGES'				=> '%d הודעות פרטיות הועברו מחדש עקב מסנני ההודעות הפרטיות.',
